write_error

Function write_error 

pub fn write_error(error: &ErrorRef<'_>, out: impl Write) -> Result<usize>
Available on crate feature blocking-io only.
Serialize error to out.

This includes a marker to allow decoding it outside a sideband channel, returning the amount of bytes written.